@@ -1,5 +1,5 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.028001';
+$POEx::IRC::Backend::VERSION = '0.029001';
 use strictures 2;
 
 use Carp;
@@ -50,7 +50,8 @@ sub get_unpacked_addr {
 }
 
 
-use Moo;
+use Moo 2;
+with 'POEx::IRC::Backend::Role::CheckAvail';
 
 
 has session_id => (
@@ -138,27 +139,11 @@ has ssl_context => (
 );
 
 
-my %_can_haz;
-
-sub has_ssl_support {
-  unless (defined $_can_haz{ssl}) {
-    try {; require POE::Component::SSLify; $_can_haz{ssl} = 1 }
-      catch {; $_can_haz{ssl} = 0 };
-  }
-  $_can_haz{ssl}
-}
-
-sub has_zlib_support {
-  unless (defined $_can_haz{zlib}) {
-    try {; require POE::Filter::Zlib::Stream; $_can_haz{zlib} = 1 }
-      catch {; $_can_haz{zlib} = 0 };
-  }
-  $_can_haz{zlib}
-}
-
 
 sub spawn {
   my ($class, %args) = @_;
+  # FIXME probably ssl_opts should be an attr and settable from here for
+  # backwards-compat:
   my $ssl_opts = delete $args{ssl_opts};
   my $self = blessed $class ? $class : $class->new(%args);
 
@@ -253,26 +238,21 @@ sub _accept_conn {
   ## Accepted connection to a listener.
   my ($self, $sock, $p_addr, $p_port, $listener_id) = @_[OBJECT, ARG0 .. ARG3];
 
-  my ($un_p_addr, $protocol);
-  if ($_[STATE] eq '_accept_conn_v6') {
-    $protocol  = 6;
-    $un_p_addr = $p_addr;
-  } else {
-    $protocol  = 4;
-    $un_p_addr = get_unpacked_addr(
-      pack_sockaddr_in($p_port, $p_addr), noserv => 1
-    );
-  }
-  my $listener = $self->listeners->{$listener_id};
+  my ($protocol, $un_p_addr) = $_[STATE] eq '_accept_conn_v6' ?
+    ( 6, $p_addr )
+    : ( 4,
+        get_unpacked_addr( pack_sockaddr_in($p_port, $p_addr), noserv => 1 )
+      ) 
+  ;
 
-  my $really_ssl;
-  if ( $listener->ssl ) {
+  my $listener = $self->listeners->{$listener_id};
+  my $using_ssl = $listener->ssl;
+  if ($using_ssl) {
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
       $sock = POE::Component::SSLify::Server_SSLify($sock, $self->ssl_context);
-      $really_ssl = 1
     } catch {
-      warn "Could not SSLify (server) socket: $_\n";
+      warn "Could not SSLify (server) socket: $_";
       undef
     } or return;
   }
@@ -286,30 +266,33 @@ sub _accept_conn {
   );
 
   unless ($wheel) {
-    carp "Wheel creation failure in _accept_conn";
+    warn "Wheel creation failure in _accept_conn";
     return
   }
 
   my ($sockaddr, $sockport) = get_unpacked_addr( 
     getsockname(
-      $really_ssl ? POE::Component::SSLify::SSLify_GetSocket($sock) : $sock
+      $using_ssl ? POE::Component::SSLify::SSLify_GetSocket($sock) : $sock
     )
   );
-  my $this_conn = POEx::IRC::Backend::Connect->new(
-    ($listener->has_args ? (args => $listener->args) : () ),
-    protocol  => $protocol,
-    wheel     => $wheel,
-    peeraddr  => $un_p_addr,
-    peerport  => $p_port,
-    sockaddr  => $sockaddr,
-    sockport  => $sockport,
-    seen      => time,
-    idle      => $listener->idle,
-  );
 
-  $self->wheels->{ $wheel->ID } = $this_conn;
+  my $w_id = $wheel->ID;
+  my $this_conn = $self->wheels->{$w_id} = 
+    POEx::IRC::Backend::Connect->new(
+      ($listener->has_args ? (args => $listener->args) : () ),
+      protocol  => $protocol,
+      wheel     => $wheel,
+      peeraddr  => $un_p_addr,
+      peerport  => $p_port,
+      sockaddr  => $sockaddr,
+      sockport  => $sockport,
+      seen      => time,
+      idle      => $listener->idle,
+      ssl       => $using_ssl,
+    );
+
   $this_conn->alarm_id(
-    $poe_kernel->delay_set( _idle_alarm => $this_conn->idle, $wheel->ID )
+    $poe_kernel->delay_set( _idle_alarm => $this_conn->idle, $w_id )
   );
 
   $poe_kernel->post( $self->controller => 
@@ -537,14 +520,14 @@ sub _connector_up {
   ## No need to try to connect out any more; remove from connectors pool:
   my $ct = delete $self->connectors->{$c_id};
 
-  my $really_ssl;
+  my $using_ssl;
   if ( $ct->ssl ) {
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
       $sock = POE::Component::SSLify::Client_SSLify(
         $sock, 0, 0, $self->ssl_context
       );
-      $really_ssl = 1
+      $using_ssl = 1
     } catch {
       warn "Could not SSLify (client) socket: $_\n";
       undef
@@ -562,13 +545,13 @@ sub _connector_up {
   );
 
   unless ($wheel) {
-    carp "Wheel creation failure in _connector_up";
+    warn "Wheel creation failure in _connector_up";
     return
   }
 
   my ($sockaddr, $sockport) = get_unpacked_addr(
     getsockname(
-      $really_ssl ? POE::Component::SSLify::SSLify_GetSocket($sock) : $sock
+      $using_ssl ? POE::Component::SSLify::SSLify_GetSocket($sock) : $sock
     )
   );
 
@@ -581,6 +564,7 @@ sub _connector_up {
     sockaddr => $sockaddr,
     sockport => $sockport,
     seen => time,
+    ssl  => $using_ssl,
   );
 
   $self->wheels->{ $wheel->ID } = $this_conn;
@@ -603,21 +587,17 @@ sub _connector_failed {
 }
 
 ## _ircsock_* handlers talk to endpoints via listeners/connectors
+
 sub _ircsock_input {
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
-  my ($input, $w_id)  = @_[ARG0, ARG1];
-
-  my $this_conn = $self->wheels->{$w_id};
-
-  ## Adjust last seen and idle alarm
+  # ($input, $w_id)  = @_[ARG0, ARG1];
+  my $this_conn = $_[OBJECT]->wheels->{ $_[ARG1] };
   $this_conn->seen( time );
-  $kernel->delay_adjust( $this_conn->alarm_id, $this_conn->idle )
+  $poe_kernel->delay_adjust( $this_conn->alarm_id, $this_conn->idle )
     if $this_conn->has_alarm_id;
 
   ## FIXME configurable raw events?
-
-  $kernel->post( $self->controller => 
-    ircsock_input => $this_conn, IRC::Message::Object->new(%$input)
+  $poe_kernel->post( $_[OBJECT]->controller => 
+    ircsock_input => $this_conn, IRC::Message::Object->new(%{ $_[ARG0] })
   );
 }
 
@@ -1257,6 +1237,8 @@ L<POEx::IRC::Backend::Listener>
 
 L<POEx::IRC::Backend::Role::Socket>
 
+L<POEx::IRC::Backend::Role::HasEndpoint>
+
 L<POEx::IRC::Backend::Role::HasWheel>
 
 L<POEx::IRC::Client::Lite> for an experimental IRC client library using this
